@@ -1,5 +1,7 @@
 package Xacobeo::UI;
 
+=encoding utf8
+
 =head1 NAME
 
 Xacobeo::UI - The graphical interface of the application.
@@ -7,7 +9,7 @@ Xacobeo::UI - The graphical interface of the application.
 =head1 SYNOPSIS
 
 	use Xacobeo::UI;
-	
+
 =head1 DESCRIPTION
 
 This package provides the graphical user interface (GUI) of the application.
@@ -20,26 +22,35 @@ The package defines the following methods:
 
 =cut
 
+use 5.006;
 use strict;
 use warnings;
 
-
+use English qw(-no_match_vars $EVAL_ERROR);
 use Glib qw(TRUE FALSE);
 use Gtk2;
 use Gtk2::GladeXML;
 use Gtk2::SimpleList;
-use Gtk2::Pango;
+use Gtk2::Pango qw(PANGO_WEIGHT_LIGHT PANGO_WEIGHT_BOLD);
 use Gtk2::SourceView;
 
 use Data::Dumper;
-use Carp;
-use File::Spec::Functions;
+use Carp qw(croak);
+use File::Spec::Functions qw(catfile);
 
 use Xacobeo;
 use Xacobeo::DomModel;
 use Xacobeo::Document;
-use Xacobeo::Utils qw(:xml :dom);
-use Xacobeo::I18n;
+use Xacobeo::Utils qw(
+	isa_dom_nodelist
+	isa_dom_namespace
+	escape_xml_attribute
+	isa_dom_boolean
+	isa_dom_number
+	isa_dom_literal
+	escape_xml_text
+);
+use Xacobeo::I18n qw(__ __x __n);
 use Xacobeo::Timer;
 use Xacobeo::Error;
 use Xacobeo::XS qw(
@@ -48,11 +59,11 @@ use Xacobeo::XS qw(
 );
 
 
-use base qw(Class::Accessor::Fast);
+use parent qw(Class::Accessor::Fast);
 __PACKAGE__->mk_accessors(
 	qw(
 		glade
-		document 
+		document
 		statusbar_context_id
 		namespaces_view
 		xpath_pango_attributes
@@ -82,23 +93,24 @@ The application's root folder.
 
 The i18n (gettext) domain to use for the translations.
 
-=back	
+=back
 
 =cut
 
 sub new {
 	# Arguments
-	my $class = shift;
-	croak 'Usage: new($app_folder, $domain)' unless @_ == 2;
-	my ($app_folder, $domain) = @_;
-	
+	my ($class, $app_folder, $domain) = @_;
+	if (! (defined $app_folder && defined $domain)) {
+		croak 'Usage: ', __PACKAGE__, '->new($app_folder, $domain)';
+	}
+
 	# Create an instance
 	my $self = bless {}, ref($class) || $class;
-	
+
 	# Create the GUI
 	$self->app_folder($app_folder);
 	$self->construct_gui($domain);
-	
+
 	# Return the new instances
 	return $self;
 }
@@ -109,11 +121,10 @@ sub new {
 #
 sub construct_gui {
 	# Arguments
-	my $self = shift;
-	my ($domain) = @_;
+	my ($self, $domain) = @_;
 
 	my $folder = $self->app_folder();
-	
+
 	# Load the GUI definition from the glade files
 	Gtk2::Glade->set_custom_handler(\&glade_custom_handler, $self);
 	my $glade = Gtk2::GladeXML->new(
@@ -122,7 +133,7 @@ sub construct_gui {
 		$domain,
 	);
 	$self->glade($glade);
-	
+
 	my $window = $self->glade->get_widget('window');
 	$window->set_title($APP_NAME);
 
@@ -140,23 +151,25 @@ sub construct_gui {
 
 	# Connect the signals to the callbacks
 	$glade->signal_autoconnect_from_package($self);
-	
+
 	# Status bar context id
 	my $statusbar = $self->glade->get_widget('statusbar');
 	$self->statusbar_context_id(
 		$statusbar->get_context_id('xpath-results')
 	);
-	
+
 	# Create the tree model for the DOM view
-	# See http://www.mail-archive.com/gtk-perl-list@gnome.org/msg03647.html	
+	# See http://www.mail-archive.com/gtk-perl-list@gnome.org/msg03647.html
 	# and http://gtk2-perl.sourceforge.net/doc/pod/Gtk2/TreeViewColumn.html#_tree_column_set_cel
 	$self->construct_dom_tree_view();
-	
+
 	# Create the list model for the Namespace view
 	$self->construct_namespaces_view();
-	
+
 	# Add the version to the about dialog
 	$self->glade->get_widget('about')->set_version($Xacobeo::VERSION);
+
+	return;
 }
 
 
@@ -172,8 +185,8 @@ sub construct_dom_tree_view {
 	my $treeview = $self->glade->get_widget('dom-tree-view');
 
 	# Create the model and link it with the view
-	Xacobeo::DomModel::create_model_with_view(
-		$treeview,	
+	Xacobeo::DomModel::create_model_with_view( ##no critic (ProhibitCallsToUnexportedSubs)
+		$treeview,
 		sub {
 			my ($node) = @_;
 			# Display the node in results text view. Temporary hack, in the future
@@ -181,6 +194,8 @@ sub construct_dom_tree_view {
 			$self->display_results($node);
 		},
 	);
+
+	return;
 }
 
 
@@ -189,9 +204,8 @@ sub construct_dom_tree_view {
 # content before displaying the new data.
 #
 sub display_xml_node {
-	my $self = shift;
-	my ($widget_name, $node) = @_;
-	
+	my ($self, $widget_name, $node) = @_;
+
 	my $namespaces = $self->document ? $self->document->namespaces : undef;
 	my $textview = $self->glade->get_widget($widget_name);
 
@@ -205,7 +219,7 @@ sub display_xml_node {
 	if (! defined $node) {
 		buffer_add($buffer, error => __("Node is undef"));
 	}
-	elsif (ref($node) eq 'Xacobeo::Error') {
+	elsif ($node->isa('Xacobeo::Error')) {
 		buffer_add($buffer, error => $node->message);
 	}
 	elsif (isa_dom_nodelist($node)) {
@@ -214,30 +228,30 @@ sub display_xml_node {
 
 		# Formatting using to indicate which result is being displayed
 		my $i = 0;
-		my $format = sprintf " %%%dd. ", length($count);
+		my $format = sprintf ' %%%dd. ', length $count;
 
 		foreach my $child (@children) {
 			# Add the result count
 			my $result = sprintf $format, ++$i;
 			buffer_add($buffer, result_count => $result);
-			
+
 			if (isa_dom_namespace($child)) {
 				# The namespaces nodes are an invention of XML::LibXML and they don't
 				# work with the XS code, we deal with them manually
 				buffer_add($buffer, syntax => ' ');
 				buffer_add($buffer, namespace_name => $child->nodeName);
-				buffer_add($buffer, syntax => '="');
-		
+				buffer_add($buffer, syntax => q{="});
+
 				my $uri = escape_xml_attribute($child->getData);
 				buffer_add($buffer, namespace_uri => $uri);
-		
-				buffer_add($buffer, syntax => '"');
+
+				buffer_add($buffer, syntax => q{"});
 			}
 			else {
 				# Performed through XS
 				xacobeo_populate_gtk_text_buffer($buffer, $child, $namespaces);
 			}
-			
+
 			buffer_add($buffer, syntax => "\n") if --$count;
 		}
 	}
@@ -268,6 +282,8 @@ sub display_xml_node {
 
 	# Scroll to tbe beginning
 	$textview->scroll_to_iter($buffer->get_start_iter, 0.0, FALSE, 0.0, 0.0);
+
+	return;
 }
 
 
@@ -277,11 +293,12 @@ sub display_xml_node {
 # view is shown. This mehtod clears the view of it's old content.
 #
 sub display_results {
-	my $self = shift;
-	my ($node) = @_;
-	
+	my ($self, $node) = @_;
+
 	$self->display_xml_node('xpath-results', $node);
 	$self->glade->get_widget('notebook')->set_current_page(0);
+
+	return;
 }
 
 
@@ -298,12 +315,12 @@ sub construct_namespaces_view {
 		'Prefix' => 'text',
 		'URI'    => 'text',
 	);
-	
-	
+
+
 	# Try to get a handle on the celleditor for the namespaces
 	$namespaces_view->set_column_editable(0, TRUE);
 	my ($editor) = $namespaces_view->get_column(0)->get_cell_renderers();
-	$editor->signal_connect(edited => 
+	$editor->signal_connect(edited =>
 		sub {
 			my ($cell, $text_path, $new_text) = @_;
 			my $path = Gtk2::TreePath->new_from_string($text_path);
@@ -312,8 +329,10 @@ sub construct_namespaces_view {
 			return FALSE;
 		}
 	);
-	
+
 	$self->namespaces_view($namespaces_view);
+
+	return;
 }
 
 
@@ -330,38 +349,36 @@ Parameters:
 
 The XML file to load.
 
-=back	
+=back
 
 =cut
 
-sub load_file { 
+sub load_file {
 	# Arguments
-	my $self = shift;
-	my ($file, $type) = @_;
+	my ($self, $file, $type) = @_;
 	$type ||= 'xml';
-	
+
 	my $timer = Xacobeo::Timer->start();
-	
+
 	# Parse the content
 	my $t_load = Xacobeo::Timer->start(__('Load document'));
 	my $document;
 	eval {
 		$document = Xacobeo::Document->new($file, $type);
-	};
-	if (my $error = $@) {
-		my $message = __x("Can't read {file}: {error}", file => $file, error => $error);
-		$self->display_statusbar_message($message);
-	}
+		1;
+	} or $self->display_statusbar_message(
+		__x("Can't read {file}: {error}", file => $file, error => $EVAL_ERROR)
+	);
 	$self->document($document);
 	undef $t_load;
-	
+
 	$self->populate_widgets($file);
-	
+
 	$timer->stop();
 	if ($document) {
 		my $format = __n(
-			"Document loaded in %.3f second", 
-			"Document loaded in %.3f seconds", 
+			"Document loaded in %.3f second",
+			"Document loaded in %.3f seconds",
 			int($timer->elapsed),
 		);
 		$self->display_statusbar_message(sprintf $format, $timer->elapsed);
@@ -370,7 +387,8 @@ sub load_file {
 		# Invoke the time elapsed this way the value is not printed to the console
 		$timer->elapsed;
 	}
-	
+
+	return;
 }
 
 
@@ -378,37 +396,38 @@ sub load_file {
 # Populates the different widgets after a document has been loaded
 #
 sub populate_widgets {
-	my $self = shift;
-	my ($file) = @_;
+	my ($self, $file) = @_;
 
 	my $glade = $self->glade;
 	$glade->get_widget('window')->set_title("$APP_NAME - $file");
-	
+
 	my $document = $self->document;
-	my ($documentNode, $namespaces) = $document ? ($document->documentNode, $document->namespaces) : (undef, {});
+	my ($document_node, $namespaces) = $document ? ($document->documentNode, $document->namespaces) : (undef, {});
 
 	# Update the text widget
 	my $t_syntax = Xacobeo::Timer->start(__('Syntax Highlight'));
-	$self->display_xml_node('xml-document', $documentNode);
+	$self->display_xml_node('xml-document', $document_node);
 	undef $t_syntax;
-	
+
 	# Clear the previous results
 	$glade->get_widget('xpath-results')->get_buffer->set_text('');
 
 	# Populate the DOM view tree
 	my $t_dom = Xacobeo::Timer->start(__('DOM Tree'));
-	$self->populate_treeview($documentNode);
+	$self->populate_treeview($document_node);
 	undef $t_dom;
-	
-	
+
+
 	# Populate the Namespaces view
-	my @namespaces = ();
+	my @namespaces;
 	while (my ($uri, $prefix) = each %{ $namespaces }) {
 		push @namespaces, [$prefix, $uri];
 	}
 	@{ $self->namespaces_view->{data} } = @namespaces;
 
 	$glade->get_widget('xpath-entry')->set_sensitive(TRUE);
+
+	return;
 }
 
 
@@ -416,12 +435,11 @@ sub populate_widgets {
 # Populates the DOM tree view.
 #
 sub populate_treeview {
-	my $self = shift;
-	my ($node) = @_;
+	my ($self, $node) = @_;
 
 	my $treeview = $self->glade->get_widget('dom-tree-view');
 	my $store = $treeview->get_model;
-	
+
 	$treeview->set_model(undef);
 	if (defined $node and defined $store) {
 		xacobeo_populate_gtk_tree_store($store, $node, $self->document->namespaces);
@@ -430,6 +448,8 @@ sub populate_treeview {
 		$store->clear();
 	}
 	$treeview->set_model($store);
+
+	return;
 }
 
 
@@ -448,18 +468,19 @@ Parameters:
 
 The XML file to load.
 
-=back	
+=back
 
 =cut
 
 sub set_xpath {
-	my $self = shift;
-	croak 'Usage: $xacobeo->set_xpath($xpath)' unless @_;
-	my ($xpath) = @_;
-	
+	my ($self, $xpath) = @_;
+	croak 'Usage: $xacobeo->set_xpath($xpath)' unless defined $xpath;
+
 	if (defined $xpath) {
 		$self->glade->get_widget('xpath-entry')->set_text($xpath);
 	}
+
+	return;
 }
 
 
@@ -467,16 +488,16 @@ sub set_xpath {
 # Populates a text tag table.
 #
 sub populate_tag_table {
-	my ($tag_table) = @_;	
-	
+	my ($tag_table) = @_;
+
 	add_tag($tag_table, result_count =>
 		family     => 'Courier 10 Pitch',
 		background => '#EDE9E3',
 		foreground => 'black',
-		style      => 'italic',,
+		style      => 'italic',
 		weight     => PANGO_WEIGHT_LIGHT
 	);
-	
+
 	# Make the boolean and number look a like
 	foreach my $name qw(boolean number) {
 		add_tag($tag_table, $name =>
@@ -485,7 +506,7 @@ sub populate_tag_table {
 			weight     => PANGO_WEIGHT_BOLD
 		);
 	}
-	
+
 	add_tag($tag_table, attribute_name =>
 		foreground => 'red',
 	);
@@ -493,75 +514,75 @@ sub populate_tag_table {
 	add_tag($tag_table, attribute_value =>
 		foreground => 'blue',
 	);
-	
+
 	add_tag($tag_table, comment =>
 		foreground => '#008000',
 		style      => 'italic',
 		weight     => PANGO_WEIGHT_LIGHT,
 	);
-	
+
 	add_tag($tag_table, dtd =>
 		foreground => '#558CBA',
 		style      => 'italic',
 	);
-	
+
 	add_tag($tag_table, element =>
 		foreground => '#800080',
 		weight     => PANGO_WEIGHT_BOLD,
 	);
-	
+
 	add_tag($tag_table, pi =>
 		foreground => '#558CBA',
 		style      => 'italic',
 	);
-	
+
 	add_tag($tag_table, pi_data =>
 		foreground => 'red',
 		style      => 'italic',
 	);
-	
+
 	add_tag($tag_table, syntax =>
 		foreground => 'black',
 		weight     => PANGO_WEIGHT_BOLD,
 	);
-	
+
 	add_tag($tag_table, literal =>
 		foreground => 'black',
 	);
-	
+
 	add_tag($tag_table, cdata =>
 		foreground => 'red',
 		weight     => PANGO_WEIGHT_BOLD
 	);
-	
+
 	add_tag($tag_table, cdata_content =>
 		foreground => 'purple',
 		weight     => PANGO_WEIGHT_LIGHT,
 		style      => 'italic',
 	);
-	
+
 	add_tag($tag_table, namespace_name =>
 		foreground => 'red',
 		style      => 'italic',
 		weight     => PANGO_WEIGHT_LIGHT,
 	);
-	
+
 	add_tag($tag_table, namespace_uri =>
 		foreground => 'blue',
 		style      => 'italic',
 		weight     => PANGO_WEIGHT_LIGHT,
 	);
-	
+
 	add_tag($tag_table, entity_ref =>
 		foreground => 'red',
 		style      => 'italic',
 		weight     => PANGO_WEIGHT_BOLD,
 	);
-	
+
 	add_tag($tag_table, error =>
 		foreground => 'red',
 	);
-	
+
 	return $tag_table;
 }
 
@@ -575,6 +596,7 @@ sub add_tag {
 	my $tag = Gtk2::TextTag->new($name);
 	$tag->set(@properties);
 	$tag_table->add($tag);
+	return;
 }
 
 
@@ -586,6 +608,7 @@ sub add_tag {
 sub buffer_add {
 	my ($buffer, $tag, $string) = @_;
 	$buffer->insert_with_tags_by_name($buffer->get_end_iter, $string, $tag);
+	return;
 }
 
 
@@ -594,6 +617,7 @@ sub buffer_add {
 #
 sub callback_window_close {
 	Gtk2->main_quit;
+	return;
 }
 
 
@@ -603,36 +627,39 @@ sub callback_window_close {
 sub callback_run_xpath {
 	# Arguments
 	my $self = shift;
-	
+
 	my $glade = $self->glade;
 
 	my $button = $glade->get_widget('xpath-evaluate');
 	return unless $button->is_sensitive;
-	
+
 	# Run the XPath expression
 	my $xpath = $glade->get_widget('xpath-entry')->get_text;
 	my $timer = Xacobeo::Timer->start();
 	my $result;
-	eval {
+	my $find_successful = eval {
 		$result = $self->document->find($xpath);
+		1;
 	};
-	my $error = $@;
+	my $error = $EVAL_ERROR;
 	$timer->stop();
-	
-	if ($error) {
-		$result = Xacobeo::Error->new(xpath => $error);
-		$self->display_statusbar_message(__("XPath query issued an error"));
-	}
-	else {
+
+	if ($find_successful) {
 		my $count = isa_dom_nodelist($result) ? $result->size : 1;
 		my $format = __n("Found %d result in %0.3fs", "Found %d results in %0.3fs", $count);
 		$self->display_statusbar_message(
 			sprintf $format, $count, $timer->elapsed
 		);
 	}
+	else {
+		$result = Xacobeo::Error->new(xpath => $error);
+		$self->display_statusbar_message(__("XPath query issued an error"));
+	}
 
 	# Display the results
 	$self->display_results($result);
+
+	return;
 }
 
 
@@ -640,20 +667,19 @@ sub callback_run_xpath {
 # Called when the XPath expression is changed, this will validate the expression.
 #
 # NOTE: There's no XPath compiler available, as a hack the XPath expression will
-#       be runned againsts an empty document, this way the result will be 
-#       instantaneous. Although, a better alternative will be to find a real 
+#       be runned againsts an empty document, this way the result will be
+#       instantaneous. Although, a better alternative will be to find a real
 #       XPath parser that can tell where the problem is.
 #
 sub callback_xpath_entry_changed {
 	# Arguments
-	my $self = shift;
-	my ($widget) = @_;
+	my ($self, $widget) = @_;
 
 	my $xpath = $widget->get_text;
-	my $pango_attributes = undef;
+	my $pango_attributes;
 	my $xpath_valid = FALSE;
 	if ($xpath) {
-	
+
 		my $button = $self->glade->get_widget('xpath-evaluate');
 		if ($self->document->validate($xpath)) {
 			# The expression is valid
@@ -669,13 +695,15 @@ sub callback_xpath_entry_changed {
 	}
 	$self->glade->get_widget('xpath-evaluate')->set_sensitive($xpath_valid);
 	$self->xpath_pango_attributes($pango_attributes);
-	
-	
+
+
 	$self->set_xpath_pango_attributes();
 
 
 	# Force a redraw
 	request_redraw($widget);
+
+	return;
 }
 
 
@@ -683,8 +711,7 @@ sub callback_xpath_entry_changed {
 # cursor which blinks periodically. The markup is sometimes forgotten between
 # redraws. This callback corrects this problem.
 sub callback_xpath_entry_expose {
-	my $self = shift;
-	my ($widget) = @_;
+	my ($self, $widget) = @_;
 	$self->set_xpath_pango_attributes();
 
 	# Continue with the events
@@ -701,14 +728,13 @@ sub callback_xpath_entry_expose {
 # while the button is still pressed.
 #
 sub callback_xpath_entry_button_press {
-	my $self = shift;
-	my ($widget, $event) = @_;
+	my ($self, $widget, $event) = @_;
 
 	if ($widget->get_text or $event->button != 1) {
 		# Propagate the event further since there's text in the widget
 		return FALSE;
 	}
-	
+
 	# Give focus to the widget but stop the text selection
 	$widget->grab_focus();
 	return TRUE;
@@ -721,6 +747,7 @@ sub callback_xpath_entry_button_press {
 sub callback_file_open {
 	my $self = shift;
 	$self->glade->get_widget('file')->show_all();
+	return;
 }
 
 
@@ -728,16 +755,16 @@ sub callback_file_open {
 # Called when the file choser has chosen a file (File > Open).
 #
 sub callback_file_selected {
-	my $self = shift;
-	my ($dialog, $response) = @_;
-	
+	my ($self, $dialog, $response) = @_;
+
 	# The open button send the response 'accept'
 	if ($response eq 'accept') {
 		my $file = $dialog->get_filename;
 		$self->load_file($file);
 	}
-	
+
 	$dialog->hide();
+	return;
 }
 
 
@@ -748,6 +775,7 @@ sub callback_about_show {
 	my $self = shift;
 	my $about = $self->glade->get_widget('about');
 	$about->show_all();
+	return;
 }
 
 
@@ -763,8 +791,7 @@ sub callback_about_show {
 # This callback can be used for all dialogs.
 #
 sub callback_dialog_hide {
-	my $self = shift;
-	my ($dialog) = @_;
+	my ($self, $dialog) = @_;
 	$dialog->hide();
 	return TRUE;
 }
@@ -775,7 +802,7 @@ sub callback_dialog_hide {
 #
 # The text region must be invalidated in order to be repainted. This is true
 # even if the markup text is the same as the one in the widget. Remember that
-# the text in the Pango markup could turn out to be the same text that was 
+# the text in the Pango markup could turn out to be the same text that was
 # previously in the widget but with new styles (this is most common when showing
 # an error with a red underline). In such case the Gtk2::Entry will not refresh
 # its appearance because the text didn't change. Here we are forcing the update.
@@ -788,6 +815,7 @@ sub request_redraw {
 	my $size = $widget->allocation;
 	my $rectangle = Gtk2::Gdk::Rectangle->new(0, 0, $size->width, $size->height);
 	$widget->window->invalidate_rect($rectangle, TRUE);
+	return;
 }
 
 
@@ -819,9 +847,10 @@ sub set_xpath_pango_attributes {
 		# Reset the attributes just in case
 		$attributes = Gtk2::Pango::AttrList->new();
 	}
-	
-	
+
+
 	$layout->set_attributes($attributes);
+	return;
 }
 
 
@@ -829,30 +858,32 @@ sub set_xpath_pango_attributes {
 # Displays the given text in the statusbar
 #
 sub display_statusbar_message {
-	my $self = shift;
-	my ($message) = @_;
-	
+	my ($self, $message) = @_;
+
 	my $statusbar = $self->glade->get_widget('statusbar');
 	my $id = $self->statusbar_context_id;
 	$statusbar->pop($id);
 	$statusbar->push($id, $message);
+	return;
 }
 
 
 sub glade_custom_handler {
-	my ($glade, $function, $name, $str1, $str2, $int1, $int2, $data) = @_;
-	my $self = $data;
-	
+	my ($glade, $function, $name, undef, undef, undef, undef, $self) = @_;
 	my $widget;
 	if ($self->can($function)) {
 		$widget = $self->$function();
 	}
 	else {
-		my $message = __x("Can't create widget {name} because method {function} is missing", function => $function, name => $name);
+		my $message = __x(
+			"Can't create widget {name} because method {function} is missing",
+			function => $function,
+			name     => $name
+		);
 		warn $message;
 		$widget = Gtk2::Label->new($message);
 	}
-	
+
 	$widget->show_all();
 	return $widget;
 }
@@ -869,13 +900,13 @@ sub create_xml_document_view {
 	$buffer->set('highlight', FALSE);
 	# This will disable the undo/redo forever
 	$buffer->begin_not_undoable_action();
-	
+
 	my $widget = Gtk2::SourceView::View->new_with_buffer($buffer);
 	$widget->set_editable(FALSE);
 	$widget->set_show_line_numbers(TRUE);
 	$widget->set_highlight_current_line(TRUE);
-	
-	return $widget;	
+
+	return $widget;
 }
 
 
@@ -889,7 +920,7 @@ sub create_xpath_results_view {
 	my $buffer = Gtk2::TextBuffer->new($tag_table);
 	my $widget = Gtk2::TextView->new_with_buffer($buffer);
 	$widget->set_editable(FALSE);
-	
+
 	return $widget;
 }
 
@@ -903,12 +934,12 @@ sub create_xpath_results_view {
 #
 sub pango_span {
 	my ($text, %attributes) = @_;
-	
-	my $pango = "<span";
+
+	my $pango = '<span';
 	while (my ($key, $value) = each %attributes) {
 		$pango .= " $key='$value'";
 	}
-	$pango .= sprintf ">%s</span>", escape_xml_text($text);
+	$pango .= sprintf '>%s</span>', escape_xml_text($text);
 
 	return Gtk2::Pango->parse_markup($pango);
 }
