@@ -1,5 +1,7 @@
 package Xacobeo::Utils;
 
+=encoding utf8
+
 =head1 NAME
 
 Xacobeo::Utils - Utilities shared among the project.
@@ -36,6 +38,7 @@ The following functions are available:
 
 =cut
 
+use 5.006;
 use strict;
 use warnings;
 
@@ -45,7 +48,7 @@ use Exporter 'import';
 our @EXPORT_OK = qw(
 	escape_xml_text
 	escape_xml_attribute
-	
+
 	isa_dom_document
 	isa_dom_element
 	isa_dom_attr
@@ -115,13 +118,17 @@ Parameters:
 
 The string to escape.
 
-=back	
+=back
 
 =cut
 
 sub escape_xml_text {
 	my ($string) = @_;
-	$string =~ s/([<>&])/$ENTITIES{$1}/eg;
+	$string =~ s{
+		( [<>&] ) # capture any literal < > &
+	}{
+		$ENTITIES{$1}
+	}egmsx; # and replace all
 	return $string;
 }
 
@@ -140,13 +147,17 @@ Parameters:
 
 The string to escape.
 
-=back	
+=back
 
 =cut
 
 sub escape_xml_attribute {
 	my ($string) = @_;
-	$string =~ s/([<>&'"])/$ENTITIES{$1}/eg;
+	$string =~ s{
+		( [<>&'"] )  # capture any literal < > & ' "
+	}{
+		$ENTITIES{$1}
+	}egmsx; # and replace all
 	return $string;
 }
 
@@ -154,7 +165,7 @@ sub escape_xml_attribute {
 
 =head2 isa_dom_document
 
-Returns true if the node is a DOM C<Document> (instance of 
+Returns true if the node is a DOM C<Document> (instance of
 L<XML::LibXML::Document>).
 
 Parameters:
@@ -165,7 +176,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -178,7 +189,7 @@ sub isa_dom_document {
 
 =head2 isa_dom_element
 
-Returns true if the node is a DOM C<Element> (instance of 
+Returns true if the node is a DOM C<Element> (instance of
 L<XML::LibXML::Element>).
 
 Parameters:
@@ -189,7 +200,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -202,7 +213,7 @@ sub isa_dom_element {
 
 =head2 isa_dom_attr
 
-Returns true if the node is a DOM C<Attribute> (instance of 
+Returns true if the node is a DOM C<Attribute> (instance of
 L<XML::LibXML::Attr>).
 
 Parameters:
@@ -213,7 +224,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -226,7 +237,7 @@ sub isa_dom_attr {
 
 =head2 isa_dom_nodelist
 
-Returns true if the node is a DOM C<NodeList> (instance of 
+Returns true if the node is a DOM C<NodeList> (instance of
 L<XML::LibXML::NodeList>).
 
 Parameters:
@@ -237,7 +248,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -250,7 +261,7 @@ sub isa_dom_nodelist {
 
 =head2 isa_dom_text
 
-Returns true if the node is a DOM C<Text> (instance of 
+Returns true if the node is a DOM C<Text> (instance of
 L<XML::LibXML::Text>).
 
 B<NOTE>: XML::LibXML considers that C<Comment> and C<CDATA> nodes are also
@@ -265,7 +276,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -280,7 +291,7 @@ sub isa_dom_text {
 
 =head2 isa_dom_comment
 
-Returns true if the node is a DOM C<Comment> (instance of 
+Returns true if the node is a DOM C<Comment> (instance of
 L<XML::LibXML::Comment>).
 
 Parameters:
@@ -291,7 +302,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -304,7 +315,7 @@ sub isa_dom_comment {
 
 =head2 isa_dom_node
 
-Returns true if the node is a DOM C<Node> (instance of 
+Returns true if the node is a DOM C<Node> (instance of
 L<XML::LibXML::Node>).
 
 Parameters:
@@ -315,7 +326,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -339,7 +350,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -352,7 +363,7 @@ sub isa_dom_pi {
 
 =head2 isa_dom_dtd
 
-Returns true if the node is a DOM C<DTD> (instance of 
+Returns true if the node is a DOM C<DTD> (instance of
 L<XML::LibXML::Dtd>).
 
 Parameters:
@@ -363,7 +374,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -376,7 +387,7 @@ sub isa_dom_dtd {
 
 =head2 isa_dom_cdata
 
-Returns true if the node is a DOM C<CDATASection> (instance of 
+Returns true if the node is a DOM C<CDATASection> (instance of
 L<XML::LibXML::CDATASection>).
 
 Parameters:
@@ -387,7 +398,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -400,7 +411,7 @@ sub isa_dom_cdata {
 
 =head2 isa_dom_namespace
 
-Returns true if the node is a C<Namespace> (instance of 
+Returns true if the node is a C<Namespace> (instance of
 L<XML::LibXML::Namespace>).
 
 B<NOTE>: The DOM doesn't define an object type named C<Namespaces> but
@@ -415,7 +426,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -428,7 +439,7 @@ sub isa_dom_namespace {
 
 =head2 isa_dom_literal
 
-Returns true if the node is a C<Literal> (instance of 
+Returns true if the node is a C<Literal> (instance of
 L<XML::LibXML::Literal>).
 
 B<NOTE>: The DOM doesn't define an object type named C<Literal> but XML::LibXML
@@ -443,7 +454,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -456,7 +467,7 @@ sub isa_dom_literal {
 
 =head2 isa_dom_boolean
 
-Returns true if the node is a C<Boolean> (instance of 
+Returns true if the node is a C<Boolean> (instance of
 L<XML::LibXML::Boolean>).
 
 B<NOTE>: The DOM doesn't define an object type named C<Boolean> but XML::LibXML
@@ -471,7 +482,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
@@ -484,7 +495,7 @@ sub isa_dom_boolean {
 
 =head2 isa_dom_number
 
-Returns true if the node is a C<Number> (instance of 
+Returns true if the node is a C<Number> (instance of
 L<XML::LibXML::Number>).
 
 B<NOTE>: The DOM doesn't define an object type named C<Number> but XML::LibXML
@@ -499,7 +510,7 @@ Parameters:
 
 The node to check.
 
-=back	
+=back
 
 =cut
 
